@@ -438,7 +438,8 @@ void QFitsView1D::paintEvent(QPaintEvent *e) {
 
         // draw gray bounding box
         pa.drawRect(0, 0, width()-1, height()-1);
-        pa.setPen(Qt::black);
+//        pa.setPen(Qt::black);
+        pa.setPen(QWidget::palette().color(QWidget::foregroundRole()));
 
         if (xmin == xmax) {
             xmin -= 1.0;
@@ -462,7 +463,8 @@ void QFitsView1D::paintEvent(QPaintEvent *e) {
             j = calcPolyline(n2data, x2data, y2data, array, ymin, ymax);
             pa.setPen(Qt::green);
             pa.drawPolyline(array.constData(), j);
-            pa.setPen(Qt::black);
+//            pa.setPen(Qt::black);
+            pa.setPen(QWidget::palette().color(QWidget::foregroundRole()));
         }
 
         drawSelection(&pa);
