@@ -331,6 +331,9 @@ bool Fits::ReadFITSData(dpint64 x1, dpint64 x2, dpint64 y1, dpint64 y2, dpint64
         case LONG_IMG:
             datatype = TINT;
             break;
+        case LONGLONG_IMG:
+            datatype = TLONGLONG;
+            break;
         case FLOAT_IMG:
             datatype = TFLOAT;
             break;
@@ -426,6 +429,9 @@ bool Fits::ReadFITSCubeImage(int which) {
         case LONG_IMG:
             datatype = TINT;
             break;
+        case LONGLONG_IMG:
+            datatype = TLONGLONG;
+            break;
         case FLOAT_IMG:
             datatype = TFLOAT;
             break;
@@ -1114,8 +1120,9 @@ int  Fits::CountExtensions(const char *fname) {
     ext = 0;
     fits_open_file(&fitsio_fd, fname, READONLY, &fitsio_status);
     if (fitsio_status != 0) {
-        if (!OpenFITS(fname))
+        if (!OpenFITS(fname, false))
             return fits_error("Could not open file for reading");
+        ext = 1;
         while (ReadFitsExtensionHeader(ext, TRUE) > 0) {
             ext++;
         }
@@ -1335,6 +1342,9 @@ bool Fits::WriteFITSExtension(const char *fname) {
     SetIntKey("GCOUNT", 1, "one data group (required keyword)");
 
 // Write the new header
+    if (!updateHeader()) {
+        return FALSE;
+    }
     fwrite(EXTENT_T, 1, 80, fd);
     fwrite(header+80, 1, HeaderLength-80, fd);
 
