@@ -67,7 +67,7 @@
 
 
 /* First part of user prologue.  */
-#line 1 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 1 "mpfit/mpfit.y"
 
 #include <iostream>
 #include <string>
@@ -77,7 +77,7 @@
 int mpfitlex();
 void mpfiterror(const char *s);
 
-#line 81 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 81 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
 
 # ifndef MPFIT_CAST
 #  ifdef __cplusplus
@@ -1104,109 +1104,109 @@ mpfitreduce:
   switch (mpfitn)
     {
   case 4: /* stmt: expr ';'  */
-#line 32 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 32 "mpfit/mpfit.y"
                         { mpfitAST = (mpfitvsp[-1].astnode); }
-#line 1110 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1110 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 5: /* stmt: expr ENTER  */
-#line 33 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 33 "mpfit/mpfit.y"
                         { std::cout << (mpfitvsp[-1].astnode)->evaluate() << std::endl; delete (mpfitvsp[-1].astnode); }
-#line 1116 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1116 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 6: /* stmt: ENTER  */
-#line 34 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 34 "mpfit/mpfit.y"
                         { std::cout << std::endl; }
-#line 1122 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1122 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 7: /* stmt: VAR '=' expr  */
-#line 35 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 35 "mpfit/mpfit.y"
                                     { mpfitassignmentNode *a = new mpfitassignmentNode(*(mpfitvsp[-2].s), (mpfitvsp[0].astnode)); a->evaluate(); delete (mpfitvsp[-2].s); delete a; }
-#line 1128 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1128 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 8: /* expr: REAL  */
-#line 38 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 38 "mpfit/mpfit.y"
                         { (mpfitval.astnode) = new mpfitnumberNode((mpfitvsp[0].i)); }
-#line 1134 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1134 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 9: /* expr: VAR  */
-#line 39 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 39 "mpfit/mpfit.y"
                         { (mpfitval.astnode) = new mpfitvariableNode(*(mpfitvsp[0].s));      delete (mpfitvsp[0].s); }
-#line 1140 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1140 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 10: /* expr: expr '+' expr  */
-#line 40 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 40 "mpfit/mpfit.y"
                         { (mpfitval.astnode) = new mpfitplusNode((mpfitvsp[-2].astnode), (mpfitvsp[0].astnode)); }
-#line 1146 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1146 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 11: /* expr: expr '-' expr  */
-#line 41 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 41 "mpfit/mpfit.y"
                         { (mpfitval.astnode) = new mpfitminusNode((mpfitvsp[-2].astnode), (mpfitvsp[0].astnode)); }
-#line 1152 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1152 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 12: /* expr: expr '*' expr  */
-#line 42 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 42 "mpfit/mpfit.y"
                         { (mpfitval.astnode) = new mpfitmultiplyNode((mpfitvsp[-2].astnode), (mpfitvsp[0].astnode)); }
-#line 1158 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1158 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 13: /* expr: expr '/' expr  */
-#line 43 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 43 "mpfit/mpfit.y"
                         { (mpfitval.astnode) = new mpfitdivideNode((mpfitvsp[-2].astnode), (mpfitvsp[0].astnode)); }
-#line 1164 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1164 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 14: /* expr: expr '^' expr  */
-#line 44 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 44 "mpfit/mpfit.y"
                         { (mpfitval.astnode) = new mpfitpowerNode((mpfitvsp[-2].astnode), (mpfitvsp[0].astnode)); }
-#line 1170 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1170 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 15: /* expr: '+' expr  */
-#line 45 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 45 "mpfit/mpfit.y"
                                 { (mpfitval.astnode) =  (mpfitvsp[0].astnode); }
-#line 1176 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1176 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 16: /* expr: '-' expr  */
-#line 46 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 46 "mpfit/mpfit.y"
                                 { (mpfitval.astnode) = new mpfitunaryMinusNode((mpfitvsp[0].astnode)); }
-#line 1182 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1182 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 17: /* expr: '(' expr ')'  */
-#line 47 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 47 "mpfit/mpfit.y"
                                 { (mpfitval.astnode) =  (mpfitvsp[-1].astnode); }
-#line 1188 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1188 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 18: /* expr: FUNC expr ')'  */
-#line 48 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 48 "mpfit/mpfit.y"
                                     { (mpfitval.astnode) = new mpfitfunctionNode(*(mpfitvsp[-2].s), (mpfitvsp[-1].astnode)); delete (mpfitvsp[-2].s); }
-#line 1194 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1194 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 19: /* expr: FUNC expr ',' expr ')'  */
-#line 49 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 49 "mpfit/mpfit.y"
                                              { (mpfitval.astnode) = new mpfitfunctionNode2(*(mpfitvsp[-4].s), (mpfitvsp[-3].astnode), (mpfitvsp[-1].astnode)); delete (mpfitvsp[-4].s); }
-#line 1200 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1200 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
   case 20: /* expr: FUNC expr ',' expr ',' expr ')'  */
-#line 50 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 50 "mpfit/mpfit.y"
                                                       { (mpfitval.astnode) = new mpfitfunctionNode3(*(mpfitvsp[-6].s), (mpfitvsp[-5].astnode), (mpfitvsp[-3].astnode), (mpfitvsp[-1].astnode)); delete (mpfitvsp[-6].s); }
-#line 1206 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1206 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
     break;
 
 
-#line 1210 "/mnt/c/ottl/project/QFitsView/build-linux/mpfitParser.cpp"
+#line 1210 "/home/ott/ottl/project/dpuser/build/mpfitParser.cpp"
 
       default: break;
     }
@@ -1399,5 +1399,5 @@ mpfitreturnlab:
   return mpfitresult;
 }
 
-#line 53 "/mnt/c/ottl/project/dpuser/mpfit/mpfit.y"
+#line 53 "mpfit/mpfit.y"
 
