@@ -292,19 +292,13 @@ qtdpuser::qtdpuser(QWidget *parent) : QWidget(parent) {
     history = new dpuserOutput(this);
     history->setFrameStyle(QFrame::NoFrame);
     history->setGeometry(0, 0, width(), height() - 20);
-//    history->setStyleSheet("border: none; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
     history->setStyleSheet("font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
     history->setText("");
 
     history->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 
     prompt = new QLabel("DPUSER> ", this);
-    prompt->setStyleSheet("border: none; background: white; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
-
-    QPalette pal(palette());
-    pal.setColor(QPalette::Window, Qt::white);
-//    setAutoFillBackground(true);
-    setPalette(pal);
+    prompt->setStyleSheet("border: none; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
 
     prompt->adjustSize();
     prompt->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
@@ -313,7 +307,7 @@ qtdpuser::qtdpuser(QWidget *parent) : QWidget(parent) {
     input = new qtdpuserInput(this);
     input->setGeometry(prompt->width() + prompt->x(), height() - 20, width() - prompt->width() - prompt->x(), 20);
     input->setFocus();
-    input->setStyleSheet("border: none; background: white; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
+    input->setStyleSheet("border: none; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
     list = new QStringList();
     connect(input, SIGNAL(returnPressed()), SLOT(appendHistory()));
     histpos = list->begin();
@@ -733,7 +727,7 @@ void qtdpuser::fontchanged() {
     if ((oldfont != settings.textfont) || (oldfontsize != settings.textsize)) {
         oldfont = settings.textfont;
         oldfontsize = settings.textsize;
-        prompt->setStyleSheet("border: none; background: white; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
+        prompt->setStyleSheet("border: none; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
         input->setStyleSheet("border: none; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
         history->setStyleSheet("border: none; font-family: " + settings.textfont + "; font-size: " + QString::number(settings.textsize) + "pt");
         prompt->adjustSize();
